%CALIBRATEJUMPDIFFUSION Minimize the sum of square difference of implied
% volatilities
% to find the best fit of a jump diffusion model to the Google option
% price data.
function [ sigma, lambda, J ] = calibrateJumpDiffusion2()
[strike,T,S0,r,mid] = googOptionData();

function e = errorFunction( x )
    sigma = exp(x(1));
    lambda = exp(x(2));
    J = exp(x(3));
    fprintf( 'Sigma=%d, lambda=%d, J=%d\n',sigma,lambda,J );
    e = 0;
    for i=1:length(strike)
        K = strike(i);
        p1 = jumpDiffusionPrice(K,T,S0,r,sigma,lambda,J);
        p2 = mid(i);
        sigma1 = impliedVolatility( K,T,S0,r,p1);
        sigma2 = impliedVolatility( K,T,S0,r,p2);
        e = e + (sigma1-sigma2)^2;
    end
end

% Note that we may only find a local minimum, so
% a good choice of x0 is important
x0 = [ log(0.25), 0.3,0.9 ];

[xOpt,~,exitFlag] = fminunc( @errorFunction, x0 );
assert(exitFlag>0);

sigma = exp( xOpt(1) );
lambda = exp( xOpt(2) );
J = exp( xOpt(3) );

end


