function [ ret, variance, w ] = markowitzOptimizeQ( q, mu, sigma )
%MARKOWITZOPTIMIZE Given a ``risk tolerance q''
%   and expected return mu for each component of the portfolio
%   and covariance matrix sigma
%   find the portfolio that minimizes w^T sigma w - q mu^T w
%   w is a vector of weights that must add up to one

H = 2*sigma;
f = -q*mu;
n = size(sigma,1);
Aeq = ones(1,n);
beq = 1;
[w,~,exitFlag] = quadprog(H,f,[],[],Aeq,beq);
assert(exitFlag>0);
ret = mu * w;
variance = w' * sigma * w;

end

