function [ ret, variance, w ] = markowitzOptimizeRetNoShortSell( r, mu, sigma )
%MARKOWITZOPTIMIZE Given a desired return r
%   and expected return mu for each component of the portfolio
%   and covariance matrix sigma
%   find the portfolio of minimum variance, short selling is not allowed

H = sigma;
n = size(sigma,1);
f = zeros(n,1);
Aeq = [ ones(1,n); mu];
beq = [1; r];
lb = zeros(n,1);

options = optimset('quadprog');
options = optimset(options,'Display','off');
[w,~,exitFlag] = quadprog(H,f,[],[],Aeq,beq,lb,[],[],options);
if (exitFlag<=0)
    ret = NaN;
    variance = NaN;
    w = [];
else    
    ret = mu * w;
    variance = w' * sigma * w;
end
end

