%OPTIMIZEUTILITY Given the PNL for each strategy in a variety of scenarios
%    (rows are scenarios, columns are strategies)
%    find the optimal quantity of each strategy to perform to maximize
%    exponential utility. This optimization is performed subject to the
%    constraint A*alpha <= b and the constraint lb<=alpha<=ub
function [ alpha ] = optimizeUtility( ...
    lambda, ...
    pnlArray, ...
    A, ...
    b, ...
    lb, ...
    ub)

function d = expectedDisutility( alpha )
    pnl = pnlArray*alpha;
    u = mean( 1 - exp(-lambda*pnl));
    d = -u;
end

nStrategies = size(pnlArray,2);
alpha0 = zeros(nStrategies,1);
alpha0(1)=1;
options = optimset('fmincon');
options = optimset(options,...
    'Display','off', 'Algorithm', 'active-set');
[alpha,~,exitFlag] = fmincon( ...
    @expectedDisutility, alpha0, A,b,[],[],lb,ub,[],options );
assert( exitFlag>0 );

end

