function utilityMaximizationExample( seed )
%UTILITYMAXIMIZATIONEXAMPLE Summary of this function goes here
%   Detailed explanation goes here

K = 100;
S0 = 100;
T = 0.5;
r = 0.03;
mu = 0.2;
sigma = 0.2;

nPaths = 10000;
nSteps = 20;

chargeToCustomer = blackScholesCallPrice(K,T,S0,r,sigma)*1.10;

rng(seed);
[deltaHedgePNL, paths] = ...
    simulateHedging(  chargeToCustomer, ...
        K, T, ...
        S0, r, mu, sigma, ...
        nPaths, nSteps, ...
        @chooseDeltaHedge  );

rng(seed); 
[stopLossPNL, ~] = ...
    simulateHedging(  chargeToCustomer, ...
        K, T, ...
        S0, r, mu, sigma, ...
        nPaths, nSteps, ...
        @chooseStopLossHedge  );
    
rng(seed); 
[noHedgePNL, ~] = ...
    simulateHedging(  chargeToCustomer, ...
        K, T, ...
        S0, r, mu, sigma, ...
        nPaths, nSteps, ...
        @chooseNoHedge  );
    
stockPNL = paths(:,end) -exp(r*T)*S0;    

pnls = [ deltaHedgePNL ...
         stopLossPNL ...
         noHedgePNL ...
         stockPNL ];
% We have two constraints, we can only sell
% a maximum of one call option and we can't
% buy call options at the given price
A = [ 1 1 1 0];
b = 1;
lb = [0 0 0 -Inf];
ub = [Inf Inf Inf Inf ];
lambda = 0.03:0.01:2;
portfolio = zeros( 4, length( lambda ));
for j=1:length( lambda )
    portfolio(:,j)=optimizeUtility( lambda(j), pnls, A, b, lb, ub );
end    
plot( lambda, portfolio );
xlabel('Lambda (risk aversion)');
ylabel('Quantity of strategy');
title('How much of each strategy is optimal?');
legend('Delta hedge strategy', 'Stop loss strategy', 'No hedge strategy', 'Invest in stock');

end

